@@ -64,6 +64,13 @@ class JoblibUtilities:
         
 class CsvUtilities:
 
+    @staticmethod
+    def to_dict_by_id(unlabeled_data):
+        result = {}
+        for item in unlabeled_data:
+            result[item[0]] = item
+        return result
+    
     @staticmethod
     def load_data(filepath,already_labeled = {}, skip_already_labeled=False):
         # csv format: [ID, TEXT, LABEL, SAMPLING_STRATEGY, CONFIDENCE]
